@@ -42,7 +42,8 @@ async def async_notification_request(
         keystroke_monitor_request=None,
         variable_monitor_request=None,
         profile_change_request=None,
-        prompt_monitor_modes=None):
+        prompt_monitor_modes=None,
+        keystroke_filter_request=None):
     """
     Requests a change to a notification subscription.
 
@@ -74,6 +75,9 @@ async def async_notification_request(
     if keystroke_monitor_request:
         request.notification_request.keystroke_monitor_request.CopyFrom(
             keystroke_monitor_request)
+    if keystroke_filter_request:
+        request.notification_request.keystroke_filter_request.CopyFrom(
+            keystroke_filter_request)
     if variable_monitor_request:
         request.notification_request.variable_monitor_request.CopyFrom(
             variable_monitor_request)
@@ -524,6 +528,14 @@ async def async_restore_arrangement(connection, name, window_id=None):
         request.saved_arrangement_request.window_id = window_id
     return await _async_call(connection, request)
 
+async def async_list_arrangements(connection):
+    """
+    Fetch a list of window arrangement names.
+    """
+    request = _alloc_request()
+    request.saved_arrangement_request.action = (
+        iterm2.api_pb2.SavedArrangementRequest.Action.Value("LIST"))
+    return await _async_call(connection, request)
 
 async def async_get_focus_info(connection):
     """
@@ -689,7 +701,7 @@ async def async_set_default_profile(connection, guid):
 
 
 async def async_get_preference(connection, key):
-    """Sets the default profile."""
+    """Gets a preference from user defaults."""
     request = _alloc_request()
     request.preferences_request.SetInParent()
     my_request = iterm2.api_pb2.PreferencesRequest.Request()
@@ -699,6 +711,18 @@ async def async_get_preference(connection, key):
     return await _async_call(connection, request)
 
 
+async def async_set_preference(connection, key, value):
+    """Sets a preference in user defaults."""
+    request = _alloc_request()
+    request.preferences_request.SetInParent()
+    my_request = iterm2.api_pb2.PreferencesRequest.Request()
+    my_request.set_preference_request.SetInParent()
+    my_request.set_preference_request.key = key
+    my_request.set_preference_request.json_value = value
+    request.preferences_request.requests.extend([my_request])
+    return await _async_call(connection, request)
+
+
 async def async_list_color_presets(connection):
     """Gets a list of color preset names."""
     request = _alloc_request()
